unit mwIDETextExpert;
{
  Vcl IDEText Expert

  Author:  Martin_Waldenburg
  Created: 05.10.97
  Demo for mwIDEStream
  Disclaimer:
  This is provided as is, expressly without a warranty of any kind.
  You use it at your own risc.

}

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, ExptIntf, ToolIntf, StdCtrls, ExtCtrls, mwIDEStream,
  ComCtrls, mwFastTime;

type
  TfmIDEText = class(TForm)
    Panel1: TPanel;
    Button1: TButton;
    Button2: TButton;
    Memo1: TMemo;
    procedure Button1Click(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure Button2Click(Sender: TObject);
  private
    { private declarations }
  public
    { public declarations }
  end;

  TIDETextExpert = class(TIExpert)
  private
    MenuItem: TIMenuItemIntf;
  protected
    procedure OnClick( Sender: TIMenuItemIntf); virtual;
  public
    constructor Create; virtual;
    destructor Destroy; override;
    function GetName: string; override;
    function GetAuthor: string; override;
    function GetStyle: TExpertStyle; override;
    function GetIDString: string; override;
  end;

procedure Register;

var
  fmIDEText: TfmIDEText;
  IDEStream: TIDEStream;

implementation

{$R *.DFM}

procedure Register;
begin
  RegisterLibraryExpert(TIDETextExpert.Create);
end;

{ TIDETextExpert code }
function TIDETextExpert.GetName: String;
begin
  Result := 'IDETextExpert'
end;

function TIDETextExpert.GetAuthor: String;
begin
  Result := 'Martin_Waldenburg'; { author }
end;

function TIDETextExpert.GetStyle: TExpertStyle;
begin
  Result := esAddIn;
end;

function TIDETextExpert.GetIDString: String;
begin
  Result := 'private.IDETextExpert';
end;

constructor TIDETextExpert.Create;
var
  Main: TIMainMenuIntf;
  ReferenceMenuItem: TIMenuItemIntf;
  Menu: TIMenuItemIntf;
begin
  inherited Create;
  MenuItem := nil;
  if ToolServices <> nil then begin { I'm an expert! }
    Main := ToolServices.GetMainMenu;
    if Main <> nil then begin { we've got the main menu! }
      try 
        { add the menu of your choice }
        ReferenceMenuItem := Main.FindMenuItem('ToolsOptionsItem');
        if ReferenceMenuItem <> nil then
        try
          Menu := ReferenceMenuItem.GetParent;
          if Menu <> nil then
          try
            MenuItem := Menu.InsertItem(ReferenceMenuItem.GetIndex+1,
                              'IDEText',
                              'IDETextExpertItem','',
                              0,0,0,
                              [mfEnabled, mfVisible], OnClick);
          finally
            Menu.DestroyMenuItem;
          end;
        finally
          ReferenceMenuItem.DestroyMenuItem;
        end;
      finally
        Main.Free;
      end;
    end;
  end;
end;

destructor TIDETextExpert.Destroy;
begin
  if MenuItem <> nil then
    MenuItem.DestroyMenuItem;
  if fmIDEText <> nil then fmIDEText.Free;
  inherited Destroy;
end;{Destroy}

procedure TIDETextExpert.OnClick( Sender: TIMenuItemIntf);
begin
  if not Assigned(fmIDEText) then
  fmIDEText:= TfmIDEText.Create(nil);
  fmIDEText.Show;
  fmIDEText.SetFocus
end;

{ TfmIDEText code }

procedure TfmIDEText.FormShow(Sender: TObject);
begin
  IDEStream:= TIDEStream.Create;
end;

procedure TfmIDEText.FormClose(Sender: TObject; var Action: TCloseAction);
begin
  IDEStream.Free;
end;

procedure TfmIDEText.Button1Click(Sender: TObject);
begin
  IDEStream.GetLines(TStringList(Memo1.Lines));
end;

procedure TfmIDEText.Button2Click(Sender: TObject);
var
  aText: PCHar;
begin
  IDEStream.Clear;
  aText:= Memo1.Lines.GetText;
  IDEStream.WriteText(aText);
end;

end.


